@@ -34,6 +34,7 @@ static char sccsid[] = "@(#) hosts_access.c 1.21 97/02/12 02:13:22";
 #include <netinet/in.h>
 #include <arpa/inet.h>
 #include <stdio.h>
+#include <stdlib.h>
 #include <syslog.h>
 #include <ctype.h>
 #include <errno.h>
@@ -54,6 +55,9 @@ extern int errno;
 
 #include "tcpd.h"
 
+unsigned long cidr_mask_addr(char *str);
+int yp_get_default_domain(char **ptr);
+
 /* Error handling. */
 
 extern jmp_buf tcpd_buf;
@@ -165,7 +169,9 @@ struct request_info *request;
 	while (match == NO && xgets(sv_list, sizeof(sv_list), fp) != 0) {
 	    if (sv_list[strlen(sv_list) - 1] != '\n') {
 		tcpd_warn("missing newline or line too long");
-		continue;
+		tcpd_warn("all the subsequent rules will be ignored");
+		match = ERR;
+		break;
 	    }
 	    if (sv_list[0] == '#' || sv_list[strspn(sv_list, " \t\r\n")] == 0)
 		continue;
